==> haskell-stack-1.4.0-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stack
version: 1.4.0
id: stack-1.4.0-8fSrQLYtCZ9AUISiyhsoWq
key: stack-1.4.0-8fSrQLYtCZ9AUISiyhsoWq
license: BSD3
maintainer: manny@fpcomplete.com
homepage: http://haskellstack.org
synopsis: The Haskell Tool Stack
description:
    Please see the README.md for usage information, and
    the wiki on Github for more details.  Also, note that
    the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.
category: Development
author: Commercial Haskell SIG
exposed: True
exposed-modules:
    Control.Concurrent.Execute Data.Aeson.Extended Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.IORef.RunOnce Data.Maybe.Extra Data.Monoid.Extra
    Data.Store.VersionTagged Data.Text.Extra Distribution.Version.Extra
    Network.HTTP.Download Network.HTTP.Download.Verified
    Options.Applicative.Args Options.Applicative.Builder.Extra
    Options.Applicative.Complicated Path.Extra Path.Find Paths_stack
    Stack.Build Stack.Build.Cache Stack.Build.ConstructPlan
    Stack.Build.Execute Stack.Build.Haddock Stack.Build.Installed
    Stack.Build.Source Stack.Build.Target Stack.BuildPlan Stack.Clean
    Stack.Config Stack.Config.Build Stack.Config.Urls
    Stack.Config.Docker Stack.Config.Nix Stack.ConfigCmd
    Stack.Constants Stack.Coverage Stack.Docker Stack.Docker.GlobalDB
    Stack.Dot Stack.Exec Stack.Fetch Stack.FileWatch Stack.GhcPkg
    Stack.Ghci Stack.Ghci.Script Stack.Hoogle Stack.IDE Stack.Image
    Stack.Init Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.ConfigParser
    Stack.Options.DockerParser Stack.Options.DotParser
    Stack.Options.ExecParser Stack.Options.GhcBuildParser
    Stack.Options.GhciParser Stack.Options.GhcVariantParser
    Stack.Options.GlobalParser Stack.Options.HaddockParser
    Stack.Options.HpcReportParser Stack.Options.LogLevelParser
    Stack.Options.NewParser Stack.Options.NixParser
    Stack.Options.PackageParser Stack.Options.ResolverParser
    Stack.Options.ScriptParser Stack.Options.SolverParser
    Stack.Options.TestParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.PackageIndex Stack.Path Stack.PrettyPrint
    Stack.Runners Stack.Script Stack.SDist Stack.Setup
    Stack.Setup.Installed Stack.SetupCmd Stack.Sig Stack.Sig.GPG
    Stack.Sig.Sign Stack.Solver Stack.Types.Build Stack.Types.BuildPlan
    Stack.Types.CompilerBuild Stack.Types.Urls Stack.Types.Compiler
    Stack.Types.Config Stack.Types.Config.Build Stack.Types.Docker
    Stack.Types.FlagName Stack.Types.GhcPkgId Stack.Types.Image
    Stack.Types.Internal Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageDump Stack.Types.PackageIdentifier
    Stack.Types.PackageIndex Stack.Types.PackageName
    Stack.Types.Resolver Stack.Types.Sig Stack.Types.StackT
    Stack.Types.TemplateName Stack.Types.Version Stack.Upgrade
    Stack.Upload Text.PrettyPrint.Leijen.Extended System.Process.Log
    System.Process.PagerEditor System.Process.Read System.Process.Run
hidden-modules: Hackage.Security.Client.Repository.HttpLib.HttpClient
abi: 5bb7ddd9a24d671a2d2e06d35eb46ef2
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/stack-1.4.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/stack-1.4.0
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/stack-1.4.0
hs-libraries: HSstack-1.4.0-8fSrQLYtCZ9AUISiyhsoWq
depends:
    Cabal-1.24.0.0 aeson-1.0.2.1-3Jq86jEoa9M6oFiloBG3wo
    annotated-wl-pprint-0.7.0-B6Xo4q6hdW98qIfojQv5XO
    ansi-terminal-0.6.2.3-AKTYR0nthhUCHW4HMZvJFX
    async-2.1.1-9CmNvQft9hOA1w6AR7WdJM
    attoparsec-0.13.1.0-2DLGgk6uYI0KCQbpcUzmmN base-4.9.0.0
    base-compat-0.9.2-81oZ9t87zdcD9ZlnIVKnPd
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY binary-0.8.3.0
    binary-tagged-0.1.4.2-IEo6P1x7k8bsFu9yprEDU
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    clock-0.7.2-bxVecpUqndAMeayDi5R9Y
    conduit-1.2.9.1-GZZC8SxHl2s2gE2ucPFZOM
    conduit-extra-1.1.15-FtUK8gS5pnWC2gXavC0Bx7 containers-0.5.7.1
    cryptonite-0.22-FrA8V8Abapg2T1hBQpVkR5
    cryptonite-conduit-0.2.0-LDvINEQCTy5Crg0mEXjZ9I deepseq-1.4.2.0
    directory-1.2.6.2 either-4.4.1.1-BezwesGY0mI4Z3143cK48b
    errors-2.1.3-8ITYmxCImbF1o6OlWIOTbu
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    extra-1.5.1-HeeVckCVl1V9DE6lYqg83I
    fast-logger-2.4.10-2uiHrtzLDm9E79SAJUHzbw
    file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ
    filelock-0.1.0.1-1BXOUOVoqUz7BiI1JXQCnD filepath-1.4.1.0
    fsnotify-0.2.1-AbK6POsDNvc2W7OcESHkcO
    generic-deriving-1.11.1-A3LIGwpr65P8ydjYiAp7Zd
    hackage-security-0.5.2.2-9MnF6D5H3VHIkpJdtoEuhq
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    hastache-0.6.1-GCCuVHv6gMaBi8dHsSmSEp
    hit-0.6.3-BuGxbq6QqmqzvG0JPF0RE hpack-0.17.0-433RfhwWl0bHrXAoYpNKC
    hpc-0.6.0.3 http-client-0.5.6.1-LjnNcxn7EAdDT87PUFggs5
    http-client-tls-0.3.4-Jtdy68AY0Ab6sKc1XAFld3
    http-conduit-2.2.3.1-4bw7GTA4KZWG1gICMzQsRz
    http-types-0.9.1-DAWlwwLyGeDDnRhY9ftEgi
    lifted-async-0.9.1.1-EbaqhI3XUWP9eTO7FEHl7i
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    memory-0.14.3-9wQQTseliVGKJ09laFleog
    microlens-0.4.8.0-9sB7IE1nvPRFUzu1zwDBDS
    microlens-mtl-0.1.10.0-Ft6UWhmjzht21aufTB77pg
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.22-5XQRUEXZThB4fRwinAGNOk
    monad-unlift-0.2.0-54TR42aNudbB2s18jYfbjS
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    open-browser-0.2.1.0-L9zpSlcLT7P1KSvFrOA2Vw
    optparse-applicative-0.13.2.0-403Af4vaGHEIyn0ZdeZhZL
    path-0.5.13-5IjC20P2EmFCsJAdNbOpJa
    path-io-1.2.2-1Qwp1OZrhHK7hE8Z8P78Ic
    persistent-2.6.1-ENXrliiaO4kGwlIcI2jSFC
    persistent-sqlite-2.6.2-KwjRkNzcwBz62GlqedW0yO
    persistent-template-2.5.2-FpjxNcQyRhkKagkksRvhk6
    pid1-0.1.0.1-8mn4OgqkObOJ7nO3SZJUm pretty-1.1.3.3 process-1.4.2.0
    project-template-0.2.0-4anxeCfLfas7lHOw6hRAxd
    regex-applicative-text-0.1.0.1-38rcZcyG4EMFvQ12jRt4xV
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    retry-0.7.4.2-GWFkfUBDuq8slJnBN66V2
    safe-0.3.14-ALdwhNEer7fKnF5VYCbXfH
    safe-exceptions-0.1.5.0-KprIFH6jKWj4auk5wxb686
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    split-0.2.3.1-IJKK4pOCYGKud0jZImZke
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    store-0.4.2-LJp3yOpg4EYEDDwK5zKYu1
    store-core-0.4-DJBczDYsgJr92c55VT9Xad
    streaming-commons-0.1.17-JBMCKUjr3AjHIyRG4GSmU7
    tar-0.5.0.3-Lj53UbIqLpELgGWYmsAfKo template-haskell-2.11.0.0
    temporary-1.2.0.4-2ZGJgvUMoC3CqxertnjRxn
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    text-binary-0.2.1.1-6SPK6a88IPhHHsLZYIQFEq
    text-metrics-0.2.0-Hn6WpAXJzhNBCvatQNDxSh time-1.6.0.1
    tls-1.3.10-8hH1FlolluXjPJN0w2xqz transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    unicode-transforms-0.2.1-8q7tL2skgYi8hmY9m3wNwt unix-2.7.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
    vector-binary-instances-0.2.3.4-1RTJjaOUh9kCFTYeGTo6CI
    yaml-0.8.22-3j3TxzXOx8BMq8g1Hz1wx
    zip-archive-0.3.0.5-4R8dq2PHAV4JpIvEapAb0Q
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/stack/html/stack.haddock
haddock-html: /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stack-1.4.0-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stack
version: 1.4.0
id: stack-1.4.0-ExSx8AwGI8lGqcEFQorDny
key: stack-1.4.0-ExSx8AwGI8lGqcEFQorDny
license: BSD3
maintainer: manny@fpcomplete.com
homepage: http://haskellstack.org
synopsis: The Haskell Tool Stack
description:
    Please see the README.md for usage information, and
    the wiki on Github for more details.  Also, note that
    the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.
category: Development
author: Commercial Haskell SIG
exposed: True
exposed-modules:
    Control.Concurrent.Execute Data.Aeson.Extended Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.IORef.RunOnce Data.Maybe.Extra Data.Monoid.Extra
    Data.Store.VersionTagged Data.Text.Extra Distribution.Version.Extra
    Network.HTTP.Download Network.HTTP.Download.Verified
    Options.Applicative.Args Options.Applicative.Builder.Extra
    Options.Applicative.Complicated Path.Extra Path.Find Paths_stack
    Stack.Build Stack.Build.Cache Stack.Build.ConstructPlan
    Stack.Build.Execute Stack.Build.Haddock Stack.Build.Installed
    Stack.Build.Source Stack.Build.Target Stack.BuildPlan Stack.Clean
    Stack.Config Stack.Config.Build Stack.Config.Urls
    Stack.Config.Docker Stack.Config.Nix Stack.ConfigCmd
    Stack.Constants Stack.Coverage Stack.Docker Stack.Docker.GlobalDB
    Stack.Dot Stack.Exec Stack.Fetch Stack.FileWatch Stack.GhcPkg
    Stack.Ghci Stack.Ghci.Script Stack.Hoogle Stack.IDE Stack.Image
    Stack.Init Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.ConfigParser
    Stack.Options.DockerParser Stack.Options.DotParser
    Stack.Options.ExecParser Stack.Options.GhcBuildParser
    Stack.Options.GhciParser Stack.Options.GhcVariantParser
    Stack.Options.GlobalParser Stack.Options.HaddockParser
    Stack.Options.HpcReportParser Stack.Options.LogLevelParser
    Stack.Options.NewParser Stack.Options.NixParser
    Stack.Options.PackageParser Stack.Options.ResolverParser
    Stack.Options.ScriptParser Stack.Options.SolverParser
    Stack.Options.TestParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.PackageIndex Stack.Path Stack.PrettyPrint
    Stack.Runners Stack.Script Stack.SDist Stack.Setup
    Stack.Setup.Installed Stack.SetupCmd Stack.Sig Stack.Sig.GPG
    Stack.Sig.Sign Stack.Solver Stack.Types.Build Stack.Types.BuildPlan
    Stack.Types.CompilerBuild Stack.Types.Urls Stack.Types.Compiler
    Stack.Types.Config Stack.Types.Config.Build Stack.Types.Docker
    Stack.Types.FlagName Stack.Types.GhcPkgId Stack.Types.Image
    Stack.Types.Internal Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageDump Stack.Types.PackageIdentifier
    Stack.Types.PackageIndex Stack.Types.PackageName
    Stack.Types.Resolver Stack.Types.Sig Stack.Types.StackT
    Stack.Types.TemplateName Stack.Types.Version Stack.Upgrade
    Stack.Upload Text.PrettyPrint.Leijen.Extended System.Process.Log
    System.Process.PagerEditor System.Process.Read System.Process.Run
hidden-modules: Hackage.Security.Client.Repository.HttpLib.HttpClient
abi: 18bf629e35491e4fc95d1f16efac95d8
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/stack-1.4.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/stack-1.4.0
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/stack-1.4.0
hs-libraries: HSstack-1.4.0-ExSx8AwGI8lGqcEFQorDny
depends:
    Cabal-1.24.0.0 aeson-1.0.2.1-FrVhYmC6JHtKJ3ssqHzInY
    annotated-wl-pprint-0.7.0-B6Xo4q6hdW98qIfojQv5XO
    ansi-terminal-0.6.2.3-AKTYR0nthhUCHW4HMZvJFX
    async-2.1.1.1-H3AbYkdNxWLAjCWaC7fyS4
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    base-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY binary-0.8.3.0
    binary-tagged-0.1.4.2-F4F9eMR1nFdHMBBIzlBO12
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    clock-0.7.2-bxVecpUqndAMeayDi5R9Y
    conduit-1.2.9.1-GZZC8SxHl2s2gE2ucPFZOM
    conduit-extra-1.1.15-7KQDtEJYa8uHngwwxCyMqo containers-0.5.7.1
    cryptonite-0.22-FrA8V8Abapg2T1hBQpVkR5
    cryptonite-conduit-0.2.0-63AtmHJdlwmL7j4rN2YmIY deepseq-1.4.2.0
    directory-1.2.6.2 either-4.4.1.1-GPwHmmh6R1fF4eaTHkyJgU
    errors-2.1.3-8ITYmxCImbF1o6OlWIOTbu
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    extra-1.5.2-FWjov7JFxoq2wD5IPaMEgG
    fast-logger-2.4.10-2uiHrtzLDm9E79SAJUHzbw
    file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ
    filelock-0.1.0.1-1BXOUOVoqUz7BiI1JXQCnD filepath-1.4.1.0
    fsnotify-0.2.1-F3SZJZ6KmEOGHbHJYEMCVP
    generic-deriving-1.11.2-QHIzAscXeYC4Er9z19sEy
    hackage-security-0.5.2.2-9MnF6D5H3VHIkpJdtoEuhq
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    hastache-0.6.1-GCCuVHv6gMaBi8dHsSmSEp
    hit-0.6.3-9gF64dg87kALIQy1ErV6WR
    hpack-0.17.0-D97upCFhCR6JORdAncrodt hpc-0.6.0.3
    http-client-0.5.6.1-BpluvowJzclKWa0VheNANV
    http-client-tls-0.3.4.1-IxjiJjr6RPvBxbXkYGAeqn
    http-conduit-2.2.3.1-BCLt1BnpYRmFMDLZQjVgHH
    http-types-0.9.1-DAWlwwLyGeDDnRhY9ftEgi
    lifted-async-0.9.1.1-Brov1Kj03bM5McrEOvXrGi
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    memory-0.14.3-9wQQTseliVGKJ09laFleog
    microlens-0.4.8.0-9sB7IE1nvPRFUzu1zwDBDS
    microlens-mtl-0.1.10.0-Ft6UWhmjzht21aufTB77pg
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.22-Gu3ykUUYuZ36T3Aum70dx7
    monad-unlift-0.2.0-54TR42aNudbB2s18jYfbjS
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    open-browser-0.2.1.0-L9zpSlcLT7P1KSvFrOA2Vw
    optparse-applicative-0.13.2.0-403Af4vaGHEIyn0ZdeZhZL
    path-0.5.13-AUELz9yOlJ45yLD05hu7sg
    path-io-1.2.2-5ZwffAgJJIH7Iyjwuua6Zh
    persistent-2.6.1-1cRnDfO46pRHU13EGUL1IM
    persistent-sqlite-2.6.2-GQptsWAhoU7IFUlaoHXaSw
    persistent-template-2.5.2-IbuTVqDgkt38fuf8PcTggS
    pid1-0.1.0.1-8mn4OgqkObOJ7nO3SZJUm pretty-1.1.3.3 process-1.4.2.0
    project-template-0.2.0-BSVLyg2Qg7666kCui0CRsx
    regex-applicative-text-0.1.0.1-38rcZcyG4EMFvQ12jRt4xV
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    retry-0.7.4.2-GWFkfUBDuq8slJnBN66V2
    safe-0.3.14-ALdwhNEer7fKnF5VYCbXfH
    safe-exceptions-0.1.5.0-KprIFH6jKWj4auk5wxb686
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    split-0.2.3.1-IJKK4pOCYGKud0jZImZke
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    store-0.4.2-IL2R1MUHBlBCU522p0eJJv
    store-core-0.4-DJBczDYsgJr92c55VT9Xad
    streaming-commons-0.1.17-6k51SJxMSKy6BYhtadRCnX
    tar-0.5.0.3-Lj53UbIqLpELgGWYmsAfKo template-haskell-2.11.0.0
    temporary-1.2.0.4-2ZGJgvUMoC3CqxertnjRxn
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    text-binary-0.2.1.1-6SPK6a88IPhHHsLZYIQFEq
    text-metrics-0.2.0-Hn6WpAXJzhNBCvatQNDxSh time-1.6.0.1
    tls-1.3.10-BQJTr2BnXSaLTqZVgcsEfK transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    unicode-transforms-0.2.1-8q7tL2skgYi8hmY9m3wNwt unix-2.7.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
    vector-binary-instances-0.2.3.5-7f4DOuSrzuCGDSfkgQUKlt
    yaml-0.8.22-DV4n1AwO9aSKGhDSvO3Duh
    zip-archive-0.3.0.5-4R8dq2PHAV4JpIvEapAb0Q
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/stack/html/stack.haddock
haddock-html: /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
